@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "js-comint" "1.2.0"
+(define-package "js-comint" "20250807.352"
   "JavaScript interpreter in window."
-  '((emacs "24.3"))
+  '((emacs "28.1"))
   :url "https://github.com/redguardtoo/js-comint"
-  :commit "0dedaf4753fbe8cdbab14aa85f05d7673cbee8b6"
-  :revdesc "0dedaf4753fb"
+  :commit "41015e29c8f51f7a927b453d97e14bc0cd7054de"
+  :revdesc "41015e29c8f5"
   :keywords '("javascript" "node" "inferior-mode" "convenience")
   :authors '(("Paul Huff" . "paul.huff@gmail.com")
              ("Stefano Mazzucco" . "MYFIRSTNAME-AT-CURSO-DOT-RE"))
